﻿using System;
using System.Windows.Forms;
using HeuristicLab.Analysis;
using HeuristicLab.MainForm;

namespace HeuristicLab.DataPreprocessing.Views {

  [View("Histogram View")]
  [Content(typeof(HistogramContent), true)]
  public partial class HistogramView : PreprocessingChartView {

    private const string HISTOGRAM_CHART_TITLE = "Histogram";

    public HistogramView() {
      InitializeComponent();
      chartType = DataRowVisualProperties.DataRowChartType.Histogram;
      chartTitle = HISTOGRAM_CHART_TITLE;
    }

    protected override void OnContentChanged()
    {
      base.OnContentChanged();
      if (Content != null)
      {
        logic = Content.ChartLogic;
        Content.AllInOneMode = false;

        classifierComboBox.Items.Clear();

        classifierComboBox.Items.Add("None");

        foreach(string var in logic.GetVariableNames()){
          classifierComboBox.Items.Add(var);
        }

        if (classifierComboBox.SelectedIndex == -1) {
          classifierComboBox.SelectedIndex = 0;
        }
      }
    }

    public new HistogramContent Content {
      get { return (HistogramContent)base.Content; }
      set { base.Content = value; }
    }

    private void classifierComboBox_SelectedIndexChanged(object sender, EventArgs e)
    {
      if (classifierComboBox.SelectedItem == null)
        return;


      if (classifierComboBox.SelectedIndex != 0)
      {
        classification = logic.GetVariableValues(classifierComboBox.SelectedItem.ToString());
      }
      else {
        classification = null;
      }

      GenerateChart();
    }
  }
}
